==> enx_uikit_flutter-1.0.3.tar.gz: lib/models/active_talker.dart <==
import 'dart:convert';
/// activeList : [{"pinned":false,"clientId":"bcbb4892-f8d8-4e76-9b33-1b302d32a482","streamId":3,"videomuted":true,"name":"Raj","videoaspectratio":"16:9","mediatype":"audiovideo"},{"pinned":false,"clientId":"7713d831-1f2d-49a5-800e-1d139ffb9919","streamId":2,"videomuted":true,"name":"Raj","videoaspectratio":"16:9","mediatype":"audiovideo"}]

ActiveTalker activeTalkerFromJson(String str) => ActiveTalker.fromJson(json.decode(str));
String activeTalkerToJson(ActiveTalker data) => json.encode(data.toJson());
class ActiveTalker {
  ActiveTalker({
      List<ActiveList>? activeList,}){
    _activeList = activeList;
}

  ActiveTalker.fromJson(dynamic json) {
    if (json['activeList'] != null) {
      _activeList = [];
      json['activeList'].forEach((v) {
        _activeList?.add(ActiveList.fromJson(v));
      });
    }
  }
  List<ActiveList>? _activeList;

  List<ActiveList>? get activeList => _activeList;

  Map<String, dynamic> toJson() {
    final map = <String, dynamic>{};
    if (_activeList != null) {
      map['activeList'] = _activeList?.map((v) => v.toJson()).toList();
    }
    return map;
  }

}

/// pinned : false
/// clientId : "bcbb4892-f8d8-4e76-9b33-1b302d32a482"
/// streamId : 3
/// videomuted : true
/// name : "Raj"
/// videoaspectratio : "16:9"
/// mediatype : "audiovideo"
//
// ActiveList activeListFromJson(String str) => ActiveList.fromJson(json.decode(str));
// String activeListToJson(ActiveList data) => json.encode(data.toJson());
class ActiveList {
  ActiveList({
      bool? pinned, 
      String? clientId, 
      int? streamId,
      bool? videomuted, 
      String? name, 
      String? videoaspectratio, 
      String? mediatype,}){
    _pinned = pinned;
    _clientId = clientId;
    _streamId = streamId;
    _videomuted = videomuted;
    _name = name;
    _videoaspectratio = videoaspectratio;
    _mediatype = mediatype;
}

  ActiveList.fromJson(dynamic json) {
    _pinned = json['pinned'];
    _clientId = json['clientId'];
    _streamId = int.parse(json['streamId']);
    _videomuted = json['videomuted'];
    _name = json['name'];
    _videoaspectratio = json['videoaspectratio'];
    _mediatype = json['mediatype'];
  }
  bool? _pinned;
  String? _clientId;
  int? _streamId;
  bool? _videomuted;
  String? _name;
  String? _videoaspectratio;
  String? _mediatype;

  bool? get pinned => _pinned;
  String? get clientId => _clientId;
  int? get streamId => _streamId;
  bool? get videomuted => _videomuted;
  String? get name => _name;
  String? get videoaspectratio => _videoaspectratio;
  String? get mediatype => _mediatype;

  Map<String, dynamic> toJson() {
    final map = <String, dynamic>{};
    map['pinned'] = _pinned;
    map['clientId'] = _clientId;
    map['streamId'] = _streamId;
    map['videomuted'] = _videomuted;
    map['name'] = _name;
    map['videoaspectratio'] = _videoaspectratio;
    map['mediatype'] = _mediatype;
    return map;
  }

}

==> enx_uikit_flutter-1.9.1.tar.gz: lib/models/active_talker.dart <==
import 'dart:convert';

/// activeList : [{"pinned":false,"clientId":"bcbb4892-f8d8-4e76-9b33-1b302d32a482","streamId":3,"videomuted":true,"name":"Raj","videoaspectratio":"16:9","mediatype":"audiovideo"},{"pinned":false,"clientId":"7713d831-1f2d-49a5-800e-1d139ffb9919","streamId":2,"videomuted":true,"name":"Raj","videoaspectratio":"16:9","mediatype":"audiovideo"}]

ActiveTalker activeTalkerFromJson(String str) =>
    ActiveTalker.fromJson(json.decode(str));
String activeTalkerToJson(ActiveTalker data) => json.encode(data.toJson());

/// pinned : false
/// clientId : "bcbb4892-f8d8-4e76-9b33-1b302d32a482"
/// streamId : 3
/// videomuted : true
/// name : "Raj"
/// videoaspectratio : "16:9"
/// mediatype : "audiovideo"
//
// ActiveList activeListFromJson(String str) => ActiveList.fromJson(json.decode(str));
// String activeListToJson(ActiveList data) => json.encode(data.toJson());
class ActiveList {
  bool? _pinned;

  String? _clientId;
  int? _streamId;
  bool? _videomuted;
  String? _name;
  String? _videoaspectratio;
  String? _mediatype;
  ActiveList({
    bool? pinned,
    String? clientId,
    int? streamId,
    bool? videomuted,
    String? name,
    String? videoaspectratio,
    String? mediatype,
  }) {
    _pinned = pinned;
    _clientId = clientId;
    _streamId = streamId;
    _videomuted = videomuted;
    _name = name;
    _videoaspectratio = videoaspectratio;
    _mediatype = mediatype;
  }
  ActiveList.fromJson(dynamic json) {
    _pinned = json['pinned'];
    _clientId = json['clientId'];
    _streamId = int.parse(json['streamId']);
    _videomuted = json['videomuted'];
    _name = json['name'];
    _videoaspectratio = json['videoaspectratio'];
    _mediatype = json['mediatype'];
  }

  String? get clientId => _clientId;
  String? get mediatype => _mediatype;
  String? get name => _name;
  bool? get pinned => _pinned;
  int? get streamId => _streamId;
  String? get videoaspectratio => _videoaspectratio;
  bool? get videomuted => _videomuted;

  Map<String, dynamic> toJson() {
    final map = <String, dynamic>{};
    map['pinned'] = _pinned;
    map['clientId'] = _clientId;
    map['streamId'] = _streamId;
    map['videomuted'] = _videomuted;
    map['name'] = _name;
    map['videoaspectratio'] = _videoaspectratio;
    map['mediatype'] = _mediatype;
    return map;
  }
}

class ActiveTalker {
  List<ActiveList>? _activeList;

  ActiveTalker({
    List<ActiveList>? activeList,
  }) {
    _activeList = activeList;
  }
  ActiveTalker.fromJson(dynamic json) {
    if (json['activeList'] != null) {
      _activeList = [];
      json['activeList'].forEach((v) {
        _activeList?.add(ActiveList.fromJson(v));
      });
    }
  }

  List<ActiveList>? get activeList => _activeList;

  Map<String, dynamic> toJson() {
    final map = <String, dynamic>{};
    if (_activeList != null) {
      map['activeList'] = _activeList?.map((v) => v.toJson()).toList();
    }
    return map;
  }
}
